==> owncloud-10.2.0.zip: owncloud/settings/l10n/zh_HK.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "密碼錯誤",
    "Saved" : "已儲存",
    "test email settings" : "測試電子郵件設定",
    "Email sent" : "郵件已傳",
    "All" : "所有",
    "Enabled" : "啟用",
    "Not enabled" : "未啟用",
    "Please wait...." : "請稍候....",
    "Disable" : "停用",
    "Enable" : "啟用",
    "Updating...." : "更新中....",
    "Updated" : "已更新",
    "Uninstalling ...." : "正在解除安裝 ....",
    "Uninstall" : "解除安裝",
    "Delete" : "刪除",
    "Sending..." : "發送中...",
    "Groups" : "群組",
    "undo" : "復原",
    "never" : "永不",
    "enabled" : "已啟用",
    "Forum" : "討論區",
    "Sharing" : "分享",
    "days" : "天",
    "Log" : "日誌",
    "None" : "空",
    "Login" : "登入",
    "Encryption" : "加密",
    "Server address" : "伺服器地址",
    "Port" : "連接埠",
    "SMTP Username" : "SMTP 使用者名稱",
    "SMTP Password" : "SMTP 密碼",
    "Android app" : "Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "Remove image" : "刪除圖片",
    "Cancel" : "取消",
    "Email" : "電郵",
    "Your email address" : "你的電郵地址",
    "Password" : "密碼",
    "New password" : "新密碼",
    "Change password" : "更改密碼",
    "Language" : "語言",
    "Help translate" : "幫忙翻譯",
    "Unlimited" : "無限",
    "Name" : "名稱",
    "Username" : "用戶名稱",
    "Version" : "版本",
    "Personal" : "個人",
    "Admin" : "管理",
    "Error" : "錯誤",
    "E-Mail" : "電郵",
    "Create" : "新增",
    "Group" : "群組",
    "Everyone" : "所有人",
    "Other" : "其他",
    "Last Login" : "最後登入",
    "Default" : "預設",
    "Share" : "分享",
    "Add" : "新增"
},
"nplurals=1; plural=0;");

==> owncloud-10.4.0.zip: owncloud/settings/l10n/zh_HK.js <==
OC.L10N.register(
    "settings",
    {
    "Saved" : "已儲存",
    "test email settings" : "測試電子郵件設定",
    "Email sent" : "郵件已傳",
    "Create" : "新增",
    "Delete" : "刪除",
    "Share" : "分享",
    "All" : "所有",
    "Enabled" : "啟用",
    "Not enabled" : "未啟用",
    "Please wait...." : "請稍候....",
    "Disable" : "停用",
    "Enable" : "啟用",
    "Updating...." : "更新中....",
    "Updated" : "已更新",
    "Uninstalling ...." : "正在解除安裝 ....",
    "Uninstall" : "解除安裝",
    "Sending..." : "發送中...",
    "Groups" : "群組",
    "undo" : "復原",
    "never" : "永不",
    "enabled" : "已啟用",
    "Forum" : "討論區",
    "Language" : "語言",
    "Sharing" : "分享",
    "days" : "天",
    "None" : "空",
    "Log" : "日誌",
    "Login" : "登入",
    "Encryption" : "加密",
    "Server address" : "伺服器地址",
    "Port" : "連接埠",
    "SMTP Username" : "SMTP 使用者名稱",
    "SMTP Password" : "SMTP 密碼",
    "Android app" : "Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "Add" : "新增",
    "Remove image" : "刪除圖片",
    "Cancel" : "取消",
    "Email" : "電郵",
    "Your email address" : "你的電郵地址",
    "Password" : "密碼",
    "New password" : "新密碼",
    "Change password" : "更改密碼",
    "Help translate" : "幫忙翻譯",
    "Name" : "名稱",
    "Username" : "用戶名稱",
    "Version" : "版本",
    "New Password" : "新密碼",
    "Personal" : "個人",
    "Admin" : "管理",
    "Other" : "其他",
    "Settings" : "設定",
    "E-Mail" : "電郵",
    "Group" : "群組",
    "Everyone" : "所有人",
    "Unlimited" : "無限",
    "Last Login" : "最後登入",
    "Default" : "預設"
},
"nplurals=1; plural=0;");
